@@ -90,16 +90,16 @@ class AudioImpulseRunner(ImpulseRunner):
         self.closed = True
 
     def classify(self):
+
         with Microphone(self.sampling_rate, CHUNK_SIZE) as mic:
             generator = mic.generator()
             features = np.array([], dtype=np.uint16)
-            for audio in generator:
-                if not self.closed:
-                    break
-                data = np.frombuffer(audio, dtype=np.uint16)
-                features = np.concatenate((features, data), axis=0)
-                while len(features) >= self.window_size:
-                    begin = now()
-                    res = super(AudioImpulseRunner, self).classify(features[:self.window_size].tolist())
-                    features = features[int(self.window_size * OVERLAP):]
-                    yield res
+            while not self.closed:
+                for audio in generator:
+                    data = np.frombuffer(audio, dtype=np.uint16)
+                    features = np.concatenate((features, data), axis=0)
+                    while len(features) >= self.window_size:
+                        begin = now()
+                        res = super(AudioImpulseRunner, self).classify(features[:self.window_size].tolist())
+                        features = features[int(self.window_size * OVERLAP):]
+                        yield res
